# Design Document: [FEATURE NAME]

<!--
Language: Generate this document in the language specified in .codexspec/config.yml
If not configured, use English.
-->

## Context

<!-- Background and current state -->

## Goals / Non-Goals

**Goals:**
- <!-- What this design aims to achieve -->

**Non-Goals:**
- <!-- What is explicitly out of scope -->

## Decisions

<!-- Key design decisions and rationale -->

### Decision 1: [Title]

**Context**: <!-- Why this decision was needed -->
**Decision**: <!-- The chosen option -->
**Rationale**: <!-- Why this option was chosen -->

## Architecture

<!-- High-level architecture description -->

```
┌─────────────────────────────────────────┐
│           Architecture Diagram           │
└─────────────────────────────────────────┘
```

## Risks / Trade-offs

| Risk | Impact | Mitigation |
|------|--------|------------|
| <!-- risk --> | <!-- impact --> | <!-- mitigation --> |

## Implementation Notes

<!-- Additional implementation considerations -->
